__project__ = "noval"
__version__ = "2022.02.28"
__url__ = "https://github.com/zlj-zz/noval.git"
__uri__ = __url__

__author__ = "Zachary Zhang"
__email__ = "zlj19971222@outlook.com"

__license__ = ""
__copyright__ = "Copyright (c) 2022 Zachary"

